From bc8b3bdb1a23d7ca0eb04954e6a9f5243e46a95f Mon Sep 17 00:00:00 2001
From: Leo <thinkabit.ukim@gmail.com>
Date: Sat, 13 Jun 2020 23:01:41 -0300
Subject: [PATCH 1/2] Install to $(PREFIX)/share/metainfo instead of appdata by
 default

As pointed out by the official documentation:

https://www.freedesktop.org/software/appstream/docs/chap-Metadata.html#spec-component-location

/usr/share/appdata is a legacy path, that is kept for backwards
compatibility purposes.

The recommended path as per 2.1.2 Filesystem locations is:

/usr/share/metainfo/%{id}.metainfo.xml
---
 Makefile | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/Makefile b/Makefile
index 64870b9..718dca2 100644
--- a/Makefile
+++ b/Makefile
@@ -3,7 +3,7 @@ SRC := vimiv
 PREFIX    := /usr
 MANPREFIX := $(PREFIX)/share/man
 LICENSEPREFIX := $(PREFIX)/share/licenses
-APPDATAPREFIX := $(PREFIX)/share/appdata
+APPDATAPREFIX := $(PREFIX)/share/metainfo
 
 default:
 	@printf "There is nothing to do.\n"
@@ -34,7 +34,7 @@ install:
 	gzip -n -9 -f $(DESTDIR)$(MANPREFIX)/man5/vimivrc.5
 	scripts/install_icons.sh $(DESTDIR)
 	install -Dm644 LICENSE $(DESTDIR)$(LICENSEPREFIX)/vimiv/LICENSE
-	install -Dm644 vimiv.appdata.xml $(DESTDIR)$(APPDATAPREFIX)/vimiv.appdata.xml
+	install -Dm644 vimiv.metainfo.xml $(DESTDIR)$(APPDATAPREFIX)/vimiv.metainfo.xml
 
 uninstall:
 	rm -rf $(DESTDIR)/etc/vimiv/
@@ -46,7 +46,7 @@ uninstall:
 	scripts/remove_icons.sh $(DESTDIR)
 	scripts/uninstall_pythonpkg.sh
 	rm -rf $(DESTDIR)$(LICENSEPREFIX)/vimiv/
-	rm -f $(DESTDIR)$(APPDATAPREFIX)/vimiv.appdata.xml
+	rm -f $(DESTDIR)$(APPDATAPREFIX)/vimiv.metainfo.xml
 
 clean:
 	rm -rf build vimiv.egg-info/

From 0f6ab8109d2cb1137f183ba720f519b929915b47 Mon Sep 17 00:00:00 2001
From: Leo <thinkabit.ukim@gmail.com>
Date: Sat, 13 Jun 2020 23:02:59 -0300
Subject: [PATCH 2/2] Rename appdata.xml to metainfo.xml

As noted in the parent commit, this is to adapt to the expected path of
the AppStream specification.
---
 vimiv.appdata.xml => vimiv.metainfo.xml | 0
 1 file changed, 0 insertions(+), 0 deletions(-)
 rename vimiv.appdata.xml => vimiv.metainfo.xml (100%)

diff --git a/vimiv.appdata.xml b/vimiv.metainfo.xml
similarity index 100%
rename from vimiv.appdata.xml
rename to vimiv.metainfo.xml
